@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -273,6 +273,8 @@ sub substitution {
         $substitute = $roll == 0 ? 'm9' : $roll == 1 ? 'm11' : 'm13';
     }
 
+    print "Sub: $chord => $substitute\n" if $self->verbose && $substitute ne $chord;
+
     return $substitute;
 }
 
@@ -290,7 +292,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -338,12 +340,12 @@ Alternative example:
     6 => [qw( 2 4 )] }
 
 The keys must start with C<1> and end on a number less than or equal
-to C<7>.  If you do not wish a scale note, that is located in the
-middle of the range, to be chosen, include it among the keys, but do
-not refer to it and do not give it any neighbors.
+to C<7>.  If you do not wish a scale note to be chosen, include it
+among the keys, but do not refer to it and do not give it any
+neighbors.
 
 For example, the chord for the 5th degree of the scale will not be
-chosen here, because no key refers to it and it has no neighbors:
+chosen here:
 
   { 1 => [qw( 1 2 3 4 6 7)],
     2 => [qw( 3 )],
@@ -355,7 +357,7 @@ chosen here, because no key refers to it and it has no neighbors:
 
 =head2 chords
 
-The chord name parts of each scale position.
+The chord names of each scale position.
 
 The number of items in this list must be equal and correspond to the
 number of keys in the B<net>.
@@ -376,6 +378,8 @@ The name of the scale.
 
 Default: C<major>
 
+Please see L<Music::Scales/SCALES> for the allowed scale names.
+
 =head2 scale_note
 
 The name of the scale starting note.
@@ -403,8 +407,8 @@ Default: C<1>
 Whether to end the progression with the tonic chord or not.
 
 If this is given as C<1> the tonic chord ends the progression.  If
-given as C<0> a neighbor of the tonic is chosen.  If given as C<-1> a
-random vertex is chosen.
+given as C<0> a neighbor of the last chord is chosen.  If given as
+C<-1> a random vertex is chosen.
 
 Default: C<1>
 
@@ -427,11 +431,11 @@ Rules:
 The subroutine to execute to determine if a chord substitution should
 happen.
 
-Default: C<sub { int rand 4 == 0 }>
+Default: C<sub { int rand 4 == 0 }> (25% of the time)
 
 =head2 flat
 
-Whether to use flats instead of sharps in the chords or not.
+Whether to use flats instead of sharps in the generated chords or not.
 
 Default: C<0>
 
@@ -443,7 +447,7 @@ Default: C<Graph::Directed>
 
 =head2 verbose
 
-Show the progress of the B<generate> method.
+Show the progress of the B<generate> and B<substitution> methods.
 
 =head1 METHODS
 
@@ -459,7 +463,7 @@ Show the progress of the B<generate> method.
     scale_note => 'A',
     octave     => 5,
     tonic      => 0,
-    resolve    => 0,
+    resolve    => -1,
     substitute => 1,
     verbose    => 1,
   );
